==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-map-series-host-component.js <==
import { __extends } from "tslib";
import { IgcSeriesComponent } from "igniteui-webcomponents-charts";
import { getAllPropertyNames, toSpinal, toPoint, fromPoint, fromRect } from "igniteui-webcomponents-core";
/**
 * Base class for hosting chart series in a IgxGeographicMap.Component
*/
var IgcGeographicMapSeriesHostComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicMapSeriesHostComponent, _super);
    function IgcGeographicMapSeriesHostComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicMapSeriesHostComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicMapSeriesHostComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicMapSeriesHostComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent == null) {
                var names = getAllPropertyNames(IgcGeographicMapSeriesHostComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = names;
            }
            return IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "isGeographic", {
        /**
         * Checks if this control is geographic coordinate system
        */
        get: function () {
            return this.i.er;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "hasMarkers", {
        /**
         * Gets whether this series supports markers
        */
        get: function () {
            return this.i.hasMarkers;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "visibleFromScale", {
        /**
         * The minimum scale at which this series becomes visible.
         * The default value for this property is 1.0, which means the series will always be visible.  At a VisibleFromScale setting of 0.0, the series will never be visible.  At a VisibleFromScale setting of 0.5, the series will be visible as long as the map is zoomed in to at least 200%.
        */
        get: function () {
            return this.i.t7;
        },
        set: function (v) {
            this.i.t7 = +v;
            this._a("visibleFromScale", this.i.t7);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "coercionMethods", {
        /**
         * Gets or sets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
        get: function () {
            return this.i.coercionMethods;
        },
        set: function (v) {
            this.i.coercionMethods = v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.notifyIndexedPropertiesChanged = function () {
        this.i.oh();
    };
    IgcGeographicMapSeriesHostComponent.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.jv(item, memberPathName);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgcGeographicMapSeriesHostComponent.prototype.getItem = function (world) {
        var iv = this.i.js(toPoint(world));
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.jg(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.je(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ia(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.tj(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.tu(toPoint(world));
        return fromRect(iv);
    };
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueMarkerBoundingBox = function (world) {
        var iv = this.i.tw(toPoint(world));
        return fromRect(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesHighValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.h6(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesHighValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.tf(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesLowValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.h8(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesLowValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.th(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValuePositionFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.tk(toPoint(mouse), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.ib(toPoint(mouse), useInterpolation, skipUnknowns);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.getItemSpan = function () {
        var iv = this.i.h1();
        return (iv);
    };
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    */
    IgcGeographicMapSeriesHostComponent.prototype.renderSeries = function (animate) {
        this.i.pr(animate);
    };
    /**
     * Called when this series' Style is updated.
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.styleUpdated = function () {
        this.i.qa();
    };
    IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = null;
    return IgcGeographicMapSeriesHostComponent;
}(IgcSeriesComponent));
export { IgcGeographicMapSeriesHostComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-map-series-host-component.js <==
import { __extends } from "tslib";
import { IgcSeriesComponent } from "igniteui-webcomponents-charts";
import { getAllPropertyNames, toSpinal, toPoint, fromPoint, fromRect } from "igniteui-webcomponents-core";
/**
 * Base class for hosting chart series in a IgxGeographicMap.Component
*/
var IgcGeographicMapSeriesHostComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicMapSeriesHostComponent, _super);
    function IgcGeographicMapSeriesHostComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicMapSeriesHostComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicMapSeriesHostComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicMapSeriesHostComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent == null) {
                var names = getAllPropertyNames(IgcGeographicMapSeriesHostComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = names;
            }
            return IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "isGeographic", {
        /**
         * Checks if this control is geographic coordinate system
        */
        get: function () {
            return this.i.fc;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "hasMarkers", {
        /**
         * Gets whether this series supports markers
        */
        get: function () {
            return this.i.hasMarkers;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "visibleFromScale", {
        /**
         * The minimum scale at which this series becomes visible.
         * The default value for this property is 1.0, which means the series will always be visible.  At a VisibleFromScale setting of 0.0, the series will never be visible.  At a VisibleFromScale setting of 0.5, the series will be visible as long as the map is zoomed in to at least 200%.
        */
        get: function () {
            return this.i.w4;
        },
        set: function (v) {
            this.i.w4 = +v;
            this._a("visibleFromScale", this.i.w4);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicMapSeriesHostComponent.prototype, "coercionMethods", {
        /**
         * Gets or sets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
        get: function () {
            return this.i.coercionMethods;
        },
        set: function (v) {
            this.i.coercionMethods = v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.notifyIndexedPropertiesChanged = function () {
        this.i.qg();
    };
    IgcGeographicMapSeriesHostComponent.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.kq(item, memberPathName);
        return (iv);
    };
    /**
     * Gets the value of a requested member path from the series.
    
    * @param memberPathName  * The property name of a valid member path for the series
    */
    IgcGeographicMapSeriesHostComponent.prototype.getMemberPathValue = function (memberPathName) {
        var iv = this.i.md(memberPathName);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgcGeographicMapSeriesHostComponent.prototype.getItem = function (world) {
        var iv = this.i.kn(toPoint(world));
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.ka(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.j8(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i5(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.we(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.wp(toPoint(world));
        return fromRect(iv);
    };
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueMarkerBoundingBox = function (world) {
        var iv = this.i.wr(toPoint(world));
        return fromRect(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesHighValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i1(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesHighValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.wa(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesLowValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i3(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesLowValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.wc(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValuePositionFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.wf(toPoint(mouse), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgcGeographicMapSeriesHostComponent.prototype.getSeriesValueFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.i6(toPoint(mouse), useInterpolation, skipUnknowns);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.getItemSpan = function () {
        var iv = this.i.iw();
        return (iv);
    };
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    */
    IgcGeographicMapSeriesHostComponent.prototype.renderSeries = function (animate) {
        this.i.rs(animate);
    };
    /**
     * Called when this series' Style is updated.
    
    */
    IgcGeographicMapSeriesHostComponent.prototype.styleUpdated = function () {
        this.i.se();
    };
    IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = null;
    return IgcGeographicMapSeriesHostComponent;
}(IgcSeriesComponent));
export { IgcGeographicMapSeriesHostComponent };
